@@ -21,6 +21,7 @@ extern SEXP glm_mcmcbas(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SE
 extern SEXP glm_sampleworep(SEXP,SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP deterministic(SEXP,SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP mcmc_new(SEXP,SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP amcmc(SEXP, SEXP,SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP mcmcbas(SEXP,SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP sampleworep_new(SEXP,SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
@@ -43,6 +44,7 @@ static const R_CallMethodDef CallEntries[] = {
   {"glm_mcmcbas",       (DL_FUNC) &glm_mcmcbas,       16},
   {"glm_sampleworep",   (DL_FUNC) &glm_sampleworep,   15},
   {"mcmc_new",          (DL_FUNC) &mcmc_new,          20},
+  {"amcmc",             (DL_FUNC) &amcmc,             21},
   {"deterministic",     (DL_FUNC) &deterministic,     11},
   {"mcmcbas",           (DL_FUNC) &mcmcbas,           20},
   {"sampleworep_new",   (DL_FUNC) &sampleworep_new,       15},
